@@ -1,7 +1,7 @@
 
 package XML::SRS;
 
-our $VERSION = "0.04_01";
+our $VERSION = "0.06_01";
 
 BEGIN { our $PROTOCOL_VERSION = "5.0" };
 use XML::SRS::Version;
@@ -37,11 +37,13 @@ use XML::SRS::Registrar::Update;
 use XML::SRS::Domain::Create;
 use XML::SRS::Domain::Update;
 use XML::SRS::Domain::Query;
+use XML::SRS::Domain::Transferred;
 use XML::SRS::UDAIValid::Query;
 use XML::SRS::Handle::Create;
 use XML::SRS::Handle::Update;
 use XML::SRS::Handle::Query;
 use XML::SRS::Message;
+use XML::SRS::Message::Ack::Response;
 use XML::SRS::GetMessages;
 use XML::SRS::AckMessage;
 
@@ -64,18 +66,18 @@ XML::SRS - Shared Registry System XML Protocol
 =head1 SYNOPSIS
 
  my $create = XML::SRS::Domain::Create->new(
-          action_id => "thinkbig.co.nz-create-".time(),
-          domain_name => "thinkbig.co.nz",
+          action_id => "kaihoro.co.nz-create-".time(),
+          domain_name => "kaihoro.co.nz",
           term => 12,
           delegate => 1,
           contact_registrant => {
-               name => "Robert Muldoon",
-               email => 'get.drunk.and.call.a.snap.election@gmail.com',
+               name => "Lord Crumb",
+               email => 'kaihoro.takeaways@gmail.com',
                address => {
                     address1 => "57 Mount Pleasant St",
                     address2 => "Burbia",
-                    city => "Ohai",
-                    region => "Southland",
+                    city => "Kaihoro",
+                    region => "Nelson",
                     cc => "NZ",
                },
                phone => {
