@@ -7,36 +7,42 @@ use Moose::Util::TypeConstraints;
 
 sub root_element { "Error" }
 
-has_attr "ErrorId" =>
+has_attr "error_id" =>
 	is => "ro",
 	isa => "XML::SRS::UID",
 	required => 1,
+	xml_name => "ErrorId",
 	;
 
 enum "XML::SRS::Error::Severity" =>
-	qw( emergency alert critical error err warning notice info );
+	qw( alert crit err );
 
-has_attr "Severity" =>
+has_attr "severity" =>
 	is => "ro",
 	isa => "XML::SRS::Error::Severity",
 	required => 1,
+	xml_name => "Severity",
 	;
 
-has_attr "Hint" =>
+has_attr "hint" =>
 	is => "ro",
 	isa => "XML::SRS::UID",  # odd
 	required => 1,
+	xml_name => "Hint",
 	;
 
-has_element "Description" =>
+has_element "desc" =>
 	is => "ro",
 	isa => "Str",
+	xml_nodeName => "Description",
 	;
 
-has_element "ErrorDetails" =>
+has_element "details" =>
 	is => "ro",
 	isa => "ArrayRef[Str]",
 	xml_min => 0,
+	xml_nodeName => "ErrorDetails",
+	auto_deref => 1,
 	;
 
 with 'XML::SRS::ActionResponse';
