@@ -3,6 +3,7 @@
 # with 'Response', which is actually 'NZSRSResponse'
 package XML::SRS::Result;
 
+use Carp;
 use Moose;
 use PRANG::Graph;
 use XML::SRS::Types;
@@ -50,23 +51,26 @@ has_attr 'client_id' =>
 	xml_name => "TransId",
 	;
 
-has_attr 'Rows' =>
+has_attr 'rows' =>
 	is => "ro",
 	isa => "XML::SRS::Number",
 	xml_required => 0,
+	xml_name => "Rows",
 	;
 
-has_attr 'MoreRowsAvailable' =>
+has_attr 'has_more_rows' =>
 	is => "ro",
 	isa => "XML::SRS::Boolean",
 	coerce => 1,
 	xml_required => 0,
+	xml_name => "MoreRowsAvailable",
 	;
 
-has_attr 'Count' =>
+has_attr 'count' =>
 	is => "ro",
 	isa => "XML::SRS::Number",
 	xml_required => 0,
+	xml_name => "Count",
 	;
 
 subtype 'XML::SRS::timeStampType'
@@ -97,10 +101,38 @@ has_element 'messages' =>
 	xml_min => 0,
 	;
 
-has_element 'response' =>
+has_element 'responses' =>
 	is => "ro",
-	isa => "XML::SRS::ActionResponse",
+	isa => "ArrayRef[XML::SRS::ActionResponse]",
 	xml_required => 0,
+	lazy => 1,
+	default => sub {
+		my $self = shift;
+		($self->has_response and defined $self->response)
+			? [ $self->response ] : [];
+	},
+	;
+
+has 'response' =>
+	is => "ro",
+	isa => "Maybe[XML::SRS::ActionResponse]",
+	predicate => "has_response",
+	lazy => 1,
+	default => sub {
+		my $self = shift;
+		my $rs_a = $self->responses;
+		if ( $rs_a and @$rs_a ) {
+			if ( @$rs_a > 1 ) {
+				confess "result has multiple responses";
+			}
+			else {
+				$rs_a->[0];
+			}
+		}
+		else {
+			undef;
+		}
+	},
 	;
 
 with 'XML::SRS::Node';
