@@ -7,8 +7,11 @@ use XML::SRS::Time;
 use Moose::Role;
 use MooseX::Method::Signatures;
 
-use MooseX::Timestamp;
-use MooseX::TimestampTZ;
+use MooseX::Timestamp qw();
+use MooseX::TimestampTZ
+	timestamptz => { -as => "_timestamptz" },
+	epoch => { -as => "_epoch" },
+	;
 
 has 'timestamp' =>
 	is => "rw",
@@ -24,12 +27,12 @@ has 'timestamp' =>
 	},
 	;
 
-method buildargs_timestamp( $inv: Timestamp $timestamp ) {
+method buildargs_timestamp( $inv: Timestamp $timestamp is coerce ) {
 	my ($date, $time) = split " ", $timestamp;
 	($inv->buildargs_time($time), $inv->buildargs_date($date));
 }
 
-method buildargs_timestamptz( $inv: TimestampTZ $timestamptz ) {
+method buildargs_timestamptz( $inv: TimestampTZ $timestamptz is coerce ) {
 	$timestamptz =~ m{
 		(?<ymd>\d+-\d+-\d+)
 		\s(?<hms>\d+:\d+:\d+)
@@ -42,8 +45,8 @@ method buildargs_timestamptz( $inv: TimestampTZ $timestamptz ) {
 	 $inv->buildargs_date($ymd));
 }
 
-method buildargs_epoch( $inv: time_t $epoch ) {
-	$inv->buildargs_timestamptz(timestamptz $epoch);
+method buildargs_epoch( $inv: time_t $epoch is coerce ) {
+	$inv->buildargs_timestamptz(_timestamptz $epoch);
 }
 
 has 'timestamptz' =>
@@ -68,7 +71,7 @@ has 'epoch' =>
 	lazy => 1,
 	default => sub {
 		my $self = shift;
-		epoch $self->timestamptz;
+		_epoch $self->timestamptz;
 	},
 	;
 
